@@ -1,5 +1,5 @@
 /* This file is part of Mailfromd.
-   Copyright (C) 2005-2022 Sergey Poznyakoff
+   Copyright (C) 2005-2023 Sergey Poznyakoff
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -115,13 +115,13 @@ mf_server_save_cmdline(int argc, char **argv)
 	x_argv[i] = NULL;
 }
 
-static RETSIGTYPE
+static void
 sig_stop(int sig)
 {
 	mfd_srvman_stop();
 }
 
-static RETSIGTYPE
+static void
 sig_restart(int sig)
 {
 	restart = 1;
