@@ -1,5 +1,5 @@
 /* This file is part of Mailfromd.
-   Copyright (C) 2005-2022 Sergey Poznyakoff
+   Copyright (C) 2005-2023 Sergey Poznyakoff
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ struct mfd_server {
 struct srvman_param srvman_param;
 
 
-typedef RETSIGTYPE (*sig_handler_t) (int);
+typedef void (*sig_handler_t) (int);
 
 union srvman_sockaddr {
 	struct sockaddr sa;
@@ -107,7 +107,7 @@ mfd_srvman_stop()
 	stop = 1;
 }
 	
-static RETSIGTYPE
+static void
 srvman_signal (int signo)
 {
 	switch (signo) {
