@@ -1,5 +1,5 @@
 /* This file is part of Mailfromd.
-   Copyright (C) 2006-2022 Sergey Poznyakoff
+   Copyright (C) 2006-2023 Sergey Poznyakoff
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -644,8 +644,8 @@ stack_find_locus(eval_environ_t env, prog_counter_t pc, prog_counter_t off, stru
 	for (i = 0; i < 32; i++, off++) {
 		if (pc > off && prog[pc - off].c_instr == instr_locus) {
 			pt->mu_file = (char*)(env->dataseg
-					      + mf_cell_c_value(prog[pc - off + 1], size));
-			pt->mu_line = mf_cell_c_value(prog[pc - off + 2], size);
+					      + mf_cell_c_value(prog[pc - off + 1], ulong));
+			pt->mu_line = mf_cell_c_value(prog[pc - off + 2], uint);
 			return pt;
 		}
 	}
